# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/kaskada/v1alpha/destinations.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from kaskada.kaskada.v1alpha import common_pb2 as kaskada_dot_kaskada_dot_v1alpha_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*kaskada/kaskada/v1alpha/destinations.proto\x12\x17kaskada.kaskada.v1alpha\x1a\x1fgoogle/api/field_behavior.proto\x1a$kaskada/kaskada/v1alpha/common.proto\"\xf8\x01\n\x08OutputTo\x12T\n\x0cobject_store\x18\x01 \x01(\x0b\x32/.kaskada.kaskada.v1alpha.ObjectStoreDestinationH\x00R\x0bobjectStore\x12\x41\n\x05redis\x18\x02 \x01(\x0b\x32).kaskada.kaskada.v1alpha.RedisDestinationH\x00R\x05redis\x12\x44\n\x06pulsar\x18\x03 \x01(\x0b\x32*.kaskada.kaskada.v1alpha.PulsarDestinationH\x00R\x06pulsarB\r\n\x0b\x64\x65stination\"\x8e\x02\n\x16ObjectStoreDestination\x12>\n\tfile_type\x18\x01 \x01(\x0e\x32!.kaskada.kaskada.v1alpha.FileTypeR\x08\x66ileType\x12*\n\x11output_prefix_uri\x18\x02 \x01(\tR\x0foutputPrefixUri\x12\x63\n\x0coutput_paths\x18\x03 \x01(\x0b\x32;.kaskada.kaskada.v1alpha.ObjectStoreDestination.ResultPathsB\x03\xe0\x41\x03R\x0boutputPaths\x1a#\n\x0bResultPaths\x12\x14\n\x05paths\x18\x01 \x03(\tR\x05paths\"\xa7\x02\n\x10RedisDestination\x12\x1b\n\thost_name\x18\x01 \x01(\tR\x08hostName\x12\x12\n\x04port\x18\x02 \x01(\x05R\x04port\x12\x17\n\x07use_tls\x18\x03 \x01(\x08R\x06useTls\x12\'\n\x0f\x64\x61tabase_number\x18\x04 \x01(\x05R\x0e\x64\x61tabaseNumber\x12\x1a\n\x08password\x18\x05 \x01(\tR\x08password\x12\x19\n\x08tls_cert\x18\x06 \x01(\tR\x07tlsCert\x12\x17\n\x07tls_key\x18\x07 \x01(\tR\x06tlsKey\x12\x1e\n\x0btls_ca_cert\x18\x08 \x01(\tR\ttlsCaCert\x12\x30\n\x14insecure_skip_verify\x18\t \x01(\x08R\x12insecureSkipVerify\"\xb8\x01\n\x11PulsarDestination\x12,\n\x12\x62roker_service_url\x18\x01 \x01(\tR\x10\x62rokerServiceUrl\x12\x16\n\x06tenant\x18\x02 \x01(\tR\x06tenant\x12\x1c\n\tnamespace\x18\x03 \x01(\tR\tnamespace\x12\x1d\n\ntopic_name\x18\x04 \x01(\tR\ttopicName\x12 \n\ttopic_url\x18\x05 \x01(\tB\x03\xe0\x41\x03R\x08topicUrlB\x81\x02\n\x1b\x63om.kaskada.kaskada.v1alphaB\x11\x44\x65stinationsProtoP\x01ZQgithub.com/kaskada-ai/kaskada/gen/proto/go/kaskada/kaskada/v1alpha;kaskadav1alpha\xa2\x02\x03KKX\xaa\x02\x17Kaskada.Kaskada.V1alpha\xca\x02\x17Kaskada\\Kaskada\\V1alpha\xe2\x02#Kaskada\\Kaskada\\V1alpha\\GPBMetadata\xea\x02\x19Kaskada::Kaskada::V1alphab\x06proto3')



_OUTPUTTO = DESCRIPTOR.message_types_by_name['OutputTo']
_OBJECTSTOREDESTINATION = DESCRIPTOR.message_types_by_name['ObjectStoreDestination']
_OBJECTSTOREDESTINATION_RESULTPATHS = _OBJECTSTOREDESTINATION.nested_types_by_name['ResultPaths']
_REDISDESTINATION = DESCRIPTOR.message_types_by_name['RedisDestination']
_PULSARDESTINATION = DESCRIPTOR.message_types_by_name['PulsarDestination']
OutputTo = _reflection.GeneratedProtocolMessageType('OutputTo', (_message.Message,), {
  'DESCRIPTOR' : _OUTPUTTO,
  '__module__' : 'kaskada.kaskada.v1alpha.destinations_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.OutputTo)
  })
_sym_db.RegisterMessage(OutputTo)

ObjectStoreDestination = _reflection.GeneratedProtocolMessageType('ObjectStoreDestination', (_message.Message,), {

  'ResultPaths' : _reflection.GeneratedProtocolMessageType('ResultPaths', (_message.Message,), {
    'DESCRIPTOR' : _OBJECTSTOREDESTINATION_RESULTPATHS,
    '__module__' : 'kaskada.kaskada.v1alpha.destinations_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.ObjectStoreDestination.ResultPaths)
    })
  ,
  'DESCRIPTOR' : _OBJECTSTOREDESTINATION,
  '__module__' : 'kaskada.kaskada.v1alpha.destinations_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.ObjectStoreDestination)
  })
_sym_db.RegisterMessage(ObjectStoreDestination)
_sym_db.RegisterMessage(ObjectStoreDestination.ResultPaths)

RedisDestination = _reflection.GeneratedProtocolMessageType('RedisDestination', (_message.Message,), {
  'DESCRIPTOR' : _REDISDESTINATION,
  '__module__' : 'kaskada.kaskada.v1alpha.destinations_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.RedisDestination)
  })
_sym_db.RegisterMessage(RedisDestination)

PulsarDestination = _reflection.GeneratedProtocolMessageType('PulsarDestination', (_message.Message,), {
  'DESCRIPTOR' : _PULSARDESTINATION,
  '__module__' : 'kaskada.kaskada.v1alpha.destinations_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.PulsarDestination)
  })
_sym_db.RegisterMessage(PulsarDestination)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033com.kaskada.kaskada.v1alphaB\021DestinationsProtoP\001ZQgithub.com/kaskada-ai/kaskada/gen/proto/go/kaskada/kaskada/v1alpha;kaskadav1alpha\242\002\003KKX\252\002\027Kaskada.Kaskada.V1alpha\312\002\027Kaskada\\Kaskada\\V1alpha\342\002#Kaskada\\Kaskada\\V1alpha\\GPBMetadata\352\002\031Kaskada::Kaskada::V1alpha'
  _OBJECTSTOREDESTINATION.fields_by_name['output_paths']._options = None
  _OBJECTSTOREDESTINATION.fields_by_name['output_paths']._serialized_options = b'\340A\003'
  _PULSARDESTINATION.fields_by_name['topic_url']._options = None
  _PULSARDESTINATION.fields_by_name['topic_url']._serialized_options = b'\340A\003'
  _OUTPUTTO._serialized_start=143
  _OUTPUTTO._serialized_end=391
  _OBJECTSTOREDESTINATION._serialized_start=394
  _OBJECTSTOREDESTINATION._serialized_end=664
  _OBJECTSTOREDESTINATION_RESULTPATHS._serialized_start=629
  _OBJECTSTOREDESTINATION_RESULTPATHS._serialized_end=664
  _REDISDESTINATION._serialized_start=667
  _REDISDESTINATION._serialized_end=962
  _PULSARDESTINATION._serialized_start=965
  _PULSARDESTINATION._serialized_end=1149
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/kaskada/v1alpha/spec.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from kaskada.kaskada.v1alpha import materialization_service_pb2 as kaskada_dot_kaskada_dot_v1alpha_dot_materialization__service__pb2
from kaskada.kaskada.v1alpha import query_service_pb2 as kaskada_dot_kaskada_dot_v1alpha_dot_query__service__pb2
from kaskada.kaskada.v1alpha import table_service_pb2 as kaskada_dot_kaskada_dot_v1alpha_dot_table__service__pb2
from kaskada.kaskada.v1alpha import view_service_pb2 as kaskada_dot_kaskada_dot_v1alpha_dot_view__service__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"kaskada/kaskada/v1alpha/spec.proto\x12\x17kaskada.kaskada.v1alpha\x1a\x35kaskada/kaskada/v1alpha/materialization_service.proto\x1a+kaskada/kaskada/v1alpha/query_service.proto\x1a+kaskada/kaskada/v1alpha/table_service.proto\x1a*kaskada/kaskada/v1alpha/view_service.proto\"\x83\x02\n\x04Spec\x12\x36\n\x06tables\x18\x01 \x03(\x0b\x32\x1e.kaskada.kaskada.v1alpha.TableR\x06tables\x12\x33\n\x05views\x18\x02 \x03(\x0b\x32\x1d.kaskada.kaskada.v1alpha.ViewR\x05views\x12\x38\n\x07queries\x18\x03 \x03(\x0b\x32\x1e.kaskada.kaskada.v1alpha.QueryR\x07queries\x12T\n\x10materializations\x18\x04 \x03(\x0b\x32(.kaskada.kaskada.v1alpha.MaterializationR\x10materializationsB\xf9\x01\n\x1b\x63om.kaskada.kaskada.v1alphaB\tSpecProtoP\x01ZQgithub.com/kaskada-ai/kaskada/gen/proto/go/kaskada/kaskada/v1alpha;kaskadav1alpha\xa2\x02\x03KKX\xaa\x02\x17Kaskada.Kaskada.V1alpha\xca\x02\x17Kaskada\\Kaskada\\V1alpha\xe2\x02#Kaskada\\Kaskada\\V1alpha\\GPBMetadata\xea\x02\x19Kaskada::Kaskada::V1alphab\x06proto3')



_SPEC = DESCRIPTOR.message_types_by_name['Spec']
Spec = _reflection.GeneratedProtocolMessageType('Spec', (_message.Message,), {
  'DESCRIPTOR' : _SPEC,
  '__module__' : 'kaskada.kaskada.v1alpha.spec_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.kaskada.v1alpha.Spec)
  })
_sym_db.RegisterMessage(Spec)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033com.kaskada.kaskada.v1alphaB\tSpecProtoP\001ZQgithub.com/kaskada-ai/kaskada/gen/proto/go/kaskada/kaskada/v1alpha;kaskadav1alpha\242\002\003KKX\252\002\027Kaskada.Kaskada.V1alpha\312\002\027Kaskada\\Kaskada\\V1alpha\342\002#Kaskada\\Kaskada\\V1alpha\\GPBMetadata\352\002\031Kaskada::Kaskada::V1alpha'
  _SPEC._serialized_start=253
  _SPEC._serialized_end=512
# @@protoc_insertion_point(module_scope)
